Signs the provided message with the supplied secret key and encodes this signature and the
associated public key into a vector of field elements in the format expected by
stdlib::crypto::dsa::ecdsa::secp256k1::verify_ecdsa_k256_keccak procedure.
Encodes the provided public key and signature into a vector of field elements in the format
expected by stdlib::crypto::dsa::ecdsa::secp256k1::verify_ecdsa_k256_keccak procedure.
Signs the provided message with the provided secret key and returns the resulting signature
encoded in the format required by the rpo_faclcon512::verify procedure, or None if the secret
key is malformed due to either incorrect length or failed decoding.
Infers the pubic key from the provided signature and message, and encodes this public key and
signature into a vector of field elements in the format expected by
stdlib::crypto::dsa::ecdsa::secp256k1::verify_ecdsa_k256_keccak procedure.